@@ -13,10 +13,11 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.user import User
 from tiddlyweb.util import sha
+
 from tiddlywebplugins.utils import get_store
 
 
-__version__ = "0.3.2"
+__version__ = "0.5.0"
 
 CONFIG_NAME = "tiddlywebconfig.py"
 
@@ -26,7 +27,7 @@ class Instance(object):
 	prefconfigured TiddlyWeb instance
 	"""
 
-	def __init__(self, directory, init_config, instance_config=None):
+	def __init__(self, directory, init_config, instance_config=None): # TODO: "create" argument to spawn and update?
 		"""
 		creates instance in given directory
 
